@@ -53,9 +53,12 @@ class Api:
         self.deprecatedPrint()
         json_data = self.manager.get_naas()
         if raw:
+            json_filtered = []
             for item in json_data:
                 if item["type"] == self.role:
                     print(item)
+                    json_filtered.append(item)
+                return json_filtered
         else:
             for item in json_data:
                 kind = None
@@ -72,7 +75,7 @@ class Api:
         token = os.urandom(30).hex()
         if not force:
             try:
-                token = self.manager.get_value(current_file)
+                token = self.manager.get_value(current_file, False)
             except:  # noqa: E722
                 pass
         url = self.manager.proxy_url(self.role, token)
